==> 1.26.2.tar.gz: lib/src/core/widgets/texts/ModernFormLabelWithInfo.dart <==
part of modern_form_core;

class ModernFormLabelWithInfo extends StatelessWidget {
  final String labelText;
  final String labelTextHelper;
  final TextStyle? labelStyle;
  final Color? iconColor;

  const ModernFormLabelWithInfo({
    Key? key,
    required this.labelText,
    required this.labelTextHelper,
    this.labelStyle,
    this.iconColor,
  }) : super(key: key);

  @override
  Widget build(BuildContext context) {
    if (ModernFormUtils.isLargeDevice) {
      return Tooltip(
        padding: EdgeInsets.all(ScreenUtil().setWidth(10)),
        message: labelTextHelper,
        child: Row(
          mainAxisSize: MainAxisSize.min,
          children: [
            Text(
              labelText,
              overflow: TextOverflow.ellipsis,
              style: labelStyle,
            ),
            Padding(
              padding: EdgeInsets.only(
                left: ScreenUtil().setWidth(2),
                bottom: ScreenUtil().setHeight(5),
              ),
              child: ModernFormInfoIcon(color: iconColor),
            )
          ],
        ),
      );
    } else {
      return Tooltip(
        padding: EdgeInsets.all(ScreenUtil().setWidth(10)),
        margin: EdgeInsets.all(ScreenUtil().setWidth(10)),
        message: labelTextHelper,
        showDuration: const Duration(seconds: 3),
        triggerMode: TooltipTriggerMode.tap,
        child: Row(
          children: [
            Text(
              labelText,
              overflow: TextOverflow.ellipsis,
              style: labelStyle,
            ),
            Padding(
              padding: EdgeInsets.only(left: ScreenUtil().setWidth(2)),
              child: ModernFormInfoIcon(color: iconColor),
            )
          ],
        ),
      );
    }
  }
}

==> 1.26.4.tar.gz: lib/src/core/widgets/texts/ModernFormLabelWithInfo.dart <==
part of modern_form_core;

class ModernFormLabelWithInfo extends StatelessWidget {
  final String labelText;
  final String labelTextHelper;
  final TextStyle? labelStyle;
  final Color? iconColor;

  const ModernFormLabelWithInfo({
    Key? key,
    required this.labelText,
    required this.labelTextHelper,
    this.labelStyle,
    this.iconColor,
  }) : super(key: key);

  @override
  Widget build(BuildContext context) {
    if (ModernFormUtils.isLargeDevice) {
      return Tooltip(
        padding: EdgeInsets.all(ScreenUtil().setWidth(10)),
        margin: EdgeInsets.symmetric(horizontal: ScreenUtil().setWidth(10)),
        message: labelTextHelper,
        child: Row(
          mainAxisSize: MainAxisSize.min,
          children: [
            Text(
              labelText,
              overflow: TextOverflow.ellipsis,
              style: labelStyle,
            ),
            Padding(
              padding: EdgeInsets.only(
                left: ScreenUtil().setWidth(2),
                bottom: ScreenUtil().setHeight(5),
              ),
              child: ModernFormInfoIcon(color: iconColor),
            )
          ],
        ),
      );
    } else {
      return Tooltip(
        padding: EdgeInsets.all(ScreenUtil().setWidth(10)),
        margin: EdgeInsets.symmetric(horizontal: ScreenUtil().setWidth(10)),
        message: labelTextHelper,
        showDuration: const Duration(seconds: 3),
        triggerMode: TooltipTriggerMode.tap,
        child: Row(
          mainAxisSize: MainAxisSize.min,
          children: [
            Text(
              labelText,
              overflow: TextOverflow.ellipsis,
              style: labelStyle,
            ),
            Padding(
              padding: EdgeInsets.only(left: ScreenUtil().setWidth(2)),
              child: ModernFormInfoIcon(color: iconColor),
            )
          ],
        ),
      );
    }
  }
}
